OC.L10N.register(
    "calendar",
    {
    "User-Session unexpectedly expired" : "Erabiltzaile-saioa ustekabean iraungi da",
    "Provided email-address is not valid" : "Emandako helbide elektronikoa ez da baliozkoa",
    "%s has published the calendar »%s«" : "%s erabiltzaileak »%s« egutegia argitaratu du",
    "Unexpected error sending email. Please contact your administrator." : "Ustekabeko errorea posta elektronikoa bidaltzean. Jarri harremanetan zure administratzailearekin.",
    "Successfully sent email to " : "Posta elektronikoa ondo bidali zaio:",
    "Hello," : "Kaixo,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Jakinarazi nahi dizugu %s erabiltzaileak »%s« egutegia argitaratu duela",
    "Open »%s«" : " Ireki »%s«",
    "Cheers!" : "Topa!",
    "Upcoming events" : "Hurrengo gertaerak",
    "Calendar" : "Egutegia",
    "A Calendar app for Nextcloud" : "Nextclouderako egutegi app-a",
    "Previous day" : "Aurreko eguna",
    "Previous week" : "Aurreko astea",
    "Previous month" : "Aurreko hilabetea",
    "Next day" : "Hurrengo eguna",
    "Next week" : "Hurrengo astea",
    "Next month" : "Hurrengo hilabetea",
    "+ New event" : "+ Gertaera berria",
    "Today" : "Gaur",
    "Day" : "Eguna",
    "Week" : "Astea",
    "Month" : "Hilabetea",
    "List" : "Zerrenda",
    "Untitled calendar" : "Izenik gabeko egutegia",
    "Edit name" : "Editatu izena",
    "Saving name …" : "Izena gordetzen …",
    "Edit color" : "Editatu kolorea",
    "Saving color …" : "Kolorea gordetzen …",
    "Copy private link" : "Kopiatu esteka pribatua",
    "Download" : "Deskargatu",
    "Unshare from me" : "Kendu nirekin partekatzea",
    "Delete" : "Ezabatu",
    "An error occurred, unable to change visibility of the calendar." : "Errore bat gertatu da, ezin da egutegiaren ikusgaitasuna aldatu.",
    "An error occurred, unable to delete the calendar." : "Errore bat gertatu da, ezin da egutegia ezabatu.",
    "Calendar link copied to clipboard." : "Egutegiko esteka arbelera kopiatu da.",
    "Calendar link could not be copied to clipboard." : "Ezin izan da egutegiko esteka arbelera kopiatu.",
    "An error occurred, unable to rename the calendar." : "Errore bat gertatu da, ezin da egutegia berrizendatu.",
    "An error occurred, unable to change the calendar's color." : "Errore bat gertatu da,  ezin da egutegiaren kolorea aldatu.",
    "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Egutegia partekatzea kenduko da segundo {countdown} barru","Egutegia partekatzea kenduko da {countdown} segundo barru"],
    "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Egutegia ezabatuko da segundo {countdown} barru","Egutegia ezabatuko da {countdown} segundo barru"],
    "Share link" : "Partekatu esteka",
    "Publish calendar" : "Argitaratu egutegia",
    "Publishing calendar" : "Egutegia argitaratzen",
    "Copy public link" : "Kopiatu esteka publikoa",
    "Send link to calendar via email" : "Bidali esteka egutegira posta elektroniko bidez",
    "Enter one address" : "Sartu helbide bat",
    "Sending email …" : "Posta elektronikoa bidaltzen …",
    "Copy subscription link" : "Kopiatu harpidetza esteka",
    "Copying link …" : "Esteka kopiatzen …",
    "Copied link" : "Esteka kopiatuta",
    "Could not copy link" : "Ezin izan da esteka kopiatu",
    "Copy embedding code" : "Kopiatu kapsulatze-kodea",
    "Copying code …" : "Kodea kopiatzen …",
    "Copied code" : "Kodea kopiatuta",
    "Could not copy code" : "Ezin izan da kodea kopiatu",
    "Delete share link" : "Ezabatu partekatze esteka",
    "Deleting share link …" : "Partekatze esteka ezabatzen  ...",
    "An error occurred, unable to publish calendar." : "Errore bat gertatu da, ezin da egutegia argitaratu",
    "An error occurred, unable to send email." : "Errore bat gertatu da, ezin da posta elektronikoa bidali.",
    "Embed code copied to clipboard." : "Kapsulatze-kodea arbelera kopiatu da.",
    "Embed code could not be copied to clipboard." : "Ezin izan da kapsulatze-kodea arbelera kopiatu.",
    "Unpublishing calendar failed" : "Egutegia desargitaratzeak huts egin du",
    "Share with users or groups" : "Partekatu erabiltzaile edo taldeekin",
    "No users or groups" : "Ez dago erabiltzaile edota talderik",
    "can edit" : "editatu dezake",
    "Unshare with {displayName}" : "Utzi {displayName} erabiltzailearekin partekatzeari",
    "An error occurred, unable to change the unshare the calendar." : "Errore bat gertatu da, ezin da egutegia partekatzeari uztea aldatu.",
    "An error occurred, unable to change the permission of the share." : "Errore bat gertatu da, ezin da partekatzearen baimena aldatu.",
    "+ New calendar" : "+ Egutegi berria",
    "New calendar" : "Egutegi berria",
    "Creating calendar …" : "Egutegia sortzen …",
    "New calendar with task list" : "Egutegi berria ataza zerrendarekin",
    "New subscription from link (read-only)" : "Harpidetza berria estekatik (irakurtzeko bakarrik)",
    "Creating subscription …" : "Harpidetza sortzen ...",
    "An error occurred, unable to create the calendar." : "Errore bat gertatu da, ezin da egutegia sortu.",
    "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Sartu baliozko esteka bat (hauetako batekin hasi behar du: http://, https://, webcal:// edo webcals://)",
    "Could not update calendar order." : "Ezin da egutegi-eskaera eguneratu.",
    "Import calendars" : "Inportatu egutegiak",
    "Please select a calendar to import into …" : "Hautatu egutegia hona inportatzeko ...",
    "Filename" : "Fitxategi-izena",
    "Calendar to import into" : "Hona inportatzeko egutegia",
    "Cancel" : "Ezeztatu",
    "_Import calendar_::_Import calendars_" : ["Inportatu egutegia","Inportatu egutegiak"],
    "{filename} is an unsupported file-type" : "{filename} sostengu gabeko fitxategi mota bat da",
    "{filename} could not be parsed" : "{filename} ezin da analizatu",
    "No valid files found, aborting import" : "Ez da baliodun fitxategirik aurkitu, inportazioa bertan behera uzten",
    "Import partially failed. Imported {accepted} out of {total}." : "Inportazioak huts egin du hein batean. Guztira {total} ziren, {accepted} inportatu dira.",
    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Behar bezala inportatu da gertaera %n.","Behar bezala inportatu dira %n gertaera."],
    "Automatic" : "Automatikoa",
    "Automatic ({detected})" : "Automatikoa ({detected})",
    "New setting was not saved successfully." : "Ezarpen berria ez da behar bezala gorde.",
    "Shortcut overview" : "Lasterbideen informazio orokorra",
    "or" : "edo",
    "Navigation" : "Nabigazioa",
    "Previous period" : "Aurreko aldia",
    "Next period" : "Hurrengo aldia",
    "Views" : "Ikuspegiak",
    "Day view" : "Egun ikuspegia",
    "Week view" : "Aste ikuspegia",
    "Month view" : "Hilabete ikuspegia",
    "Actions" : "Ekintzak",
    "Create event" : "Sortu gertaera",
    "Show shortcuts" : "Erakutsi lasterbideak",
    "Enable birthday calendar" : "Gaitu urtebetetzeen egutegia",
    "Show tasks in calendar" : "Erakutsi zereginak egutegian",
    "Enable simplified editor" : "Gaitu editore sinplifikatua",
    "Limit visible events per view" : "Mugatu ikusgai dauden gertaerak",
    "Show weekends" : "Erakutsi asteburuak",
    "Show week numbers" : "Erakutsi aste zenbakiak",
    "Copy primary CalDAV address" : "Kopiatu CalDAV helbide nagusia",
    "Copy iOS/macOS CalDAV address" : "Kopiatu iOS/macOS CalDAV helbidea",
    "Show keyboard shortcuts" : "Erakutsi teklatuaren lasterbideak",
    "Settings & import" : "Ezarpenak eta inportazioa",
    "CalDAV link copied to clipboard." : "CalDAV esteka arbelera kopiatu da.",
    "CalDAV link could not be copied to clipboard." : "Ezin izan da CalDAV helbidea arbelera kopiatu.",
    "before at" : "lehenago hemen",
    "Notification" : "Jakinarazpena",
    "Email" : "Mezu elektronikoa",
    "Audio notification" : "Audio jakinarazpena",
    "Other notification" : "Bestelako jakinarazpena",
    "Relative to event" : "Gertaerarekiko",
    "On date" : "Epean",
    "Edit time" : "Editatu ordua",
    "Save time" : "Gorde ordua",
    "Remove reminder" : "Kendu abisua",
    "on" : "noiz",
    "at" : "non",
    "+ Add reminder" : "+ Gehitu abisua",
    "_second_::_seconds_" : ["segundo","segundo"],
    "_minute_::_minutes_" : ["minutu","minutu"],
    "_hour_::_hours_" : ["ordu","ordu"],
    "_day_::_days_" : ["egun","egun"],
    "_week_::_weeks_" : ["aste","aste"],
    "No reminders yet" : "Abisurik ez oraindik",
    "Availability of attendees, resources and rooms" : "Partaide, baliabide eta gelen eskuragarritasuna",
    "Busy (tentative)" : "Lanpetuta (behin-behinean)",
    "Busy" : "Lanpetua",
    "Out of office" : "Bulegotik kanpo",
    "Unknown" : "Ezezaguna",
    "{name} accepted your invitation." : "{name} erabiltzaileak zure gonbidapena onartu du.",
    "{name} accepted {organizerName}'s invitation." : "{name} erabiltzaileak {organizerName} erabiltzailearen gonbidapena onartu du.",
    "{name} declined your invitation." : "{name} erabiltzaileak zure gonbidapenari uko egin dio.",
    "{name} declined {organizerName}'s invitation." : "{name} erabiltzaileak {organizerName} erabiltzailearen gonbidapenari uko egin dio.",
    "{name} has delegated their invitation." : "{name} erabiltzaileak bere gonbidapena eskuordetu du.",
    "{name} marked their participation as tentative." : "{name} erabiltzaileak bere parte-hartzea behin behineko bezala markatu du.",
    "{name} did not respond to your invitation yet." : "{name} erabiltzaileak ez dio zure gonbidapenari erantzun oraindik.",
    "{name} did not respond to {organizerName}'s invitation yet." : "{name} erabiltzaileak ez dio {organizerName} erabiltzailearen gonbidapenari erantzun oraindik.",
    "Create Talk room for this event" : "Sortu Talk gela gertaera honentzat",
    "Show busy times" : "Erakutsi denbora lanpetuta",
    "Successfully appended link to talk room to description." : "Ondo erantsi zaio esteka hizketa gelaren deskribapenari.",
    "Error creating Talk room" : "Errorea Talk gela sortzean",
    "Send e-mail" : "Bidali posta elektronikoa",
    "Chairperson" : "Presidente",
    "Required participant" : "Beharrezko partaidea",
    "Optional participant" : "Hautazko partaidea",
    "Non-participant" : "Ez da partaidea",
    "Remove attendee" : "Kendu partaidea",
    "Search for e-mails, users, contacts, resources or rooms" : "Bilatu helbide elektronikoak, erabiltzaileak, kontaktuak, baliabideak edo gelak",
    "No match found" : "Ez da emaitzarik aurkitu",
    "No attendees yet" : "Partaiderik ez oraindik",
    "(organizer)" : "(antolatzailea)",
    "To send out invitations and handle responses, [linkopen]add your email address in personal settings[linkclose]." : "Gonbidapenak bidali eta erantzunak kudeatzeko, [linkopen] gehitu zure posta helbidea ezarpen pertsonaletan[linkclose].",
    "Remove color" : "Kendu kolorea",
    "Event title" : "Gertaeraren izenburua",
    "All day" : "Egun osoa",
    "Can not modify all-day setting for events that are part of a recurrence-set." : "Ezin dira egun osoko ezarpenak aldatu errepikapen sorta bateko ekitaldientzat.",
    "from {startDate}" : "noiztik {startDate}",
    "from {startDate} at {startTime}" : "noiztik {startDate},  {startTime}",
    "to {endDate}" : "noiz arte {endDate}",
    "to {endDate} at {endTime}" : "noiz arte {endDate}, {endTime}",
    "End repeat" : "Amaitu errepikapena",
    "Select to end repeat" : "Hautatu errepikapena amaitzeko",
    "never" : "inoiz ez",
    "on date" : "epean",
    "after" : "gero",
    "_time_::_times_" : ["aldiz","aldiz"],
    "This event is the recurrence-exception of a recurrence-set. You can not add a recurrence-rule to it." : "Ekitaldi hau errepikapen sorta bateko errepikapen salbuespena da. Ezin diozu errepikapen araurik ezarri.",
    "first" : "lehena",
    "third" : "hirugarrena",
    "fourth" : "laugarrena",
    "fifth" : "bosgarrena",
    "second to last" : "azken-aurrekoa",
    "last" : "azkena",
    "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Errepikapen arauan egindako aldaketak gertaera honentzat eta etorkizunekoentzat bakarrik aplikatuko dira.",
    "Repeat" : "Errepikatu",
    "Repeat every" : "Errepikatu zenbatero",
    "By day of the month" : "Hileko egunaren arabera",
    "On the" : "Honetan",
    "_month_::_months_" : ["hilabete","hilabete"],
    "_year_::_years_" : ["urte","urte"],
    "Monday" : "Astelehena",
    "weekday" : "asteguna",
    "weekend day" : "asteburuko eguna",
    "Summary" : "Laburpena",
    "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "Gertaera honen errepikapen definizioa ez du guztiz onartzen Nextcloud-ek. Errepikapen aukerak editatzen badituzu, errepikapen batzuk galdu litezke.",
    "More" : "Gehiago",
    "Save" : "Gorde",
    "Update" : "Eguneratu",
    "Update this occurrence" : "Eguneratu gertaera hau",
    "Update this and all future" : "Eguneratu hau eta etorkizuneko guztiak",
    "Public calendar does not exist" : "Egutegi publikoa ez da existitzen",
    "Maybe the share was deleted or has expired?" : "Agian, partekatutakoa ezabatu egin da edo iraungita geratu da?",
    "Please select a timezone:" : "Mesedez aukeratu ordu-zona bat:",
    "Pick a time" : "Aukeratu ordua",
    "Pick a date" : "Aukeratu eguna",
    "from {formattedDate}" : "{formattedDate}(e)tik ",
    "to {formattedDate}" : "{formattedDate} arte ",
    "on {formattedDate}" : "{formattedDate}(e)an",
    "from {formattedDate} at {formattedTime}" : "{formattedDate}tik {formattedTime}ra",
    "to {formattedDate} at {formattedTime}" : "{formattedDate} arte {formattedTime}etan",
    "on {formattedDate} at {formattedTime}" : "{formattedDate}(e)an {formattedTime}etan",
    "{formattedDate} at {formattedTime}" : "{formattedDate}(e)an {formattedTime}etan",
    "Please enter a valid date" : "Sartu baliozko data",
    "Please enter a valid date and time" : "Sartu baliozko data eta ordua",
    "Type to search timezone" : "Idatzi ordu-zona bat bilatzeko",
    "Personal" : "Pertsonala",
    "The automatic timezone detection determined your timezone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your timezone manually in the calendar settings." : "Ordu-eremu detekzio automatikoak zehaztu du zure ordu-eremua UTC dela. Hau seguru aski zure nabigatzailearen segurtasun neurrien ondorio da. Zehaztu ezazu zure ordu-eremua eskuz egutegiaren ezarpenetan.",
    "Your configured timezone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your timezone in the settings and report this issue." : "Ezarrita daukazun ordu-eremua ({timezoneId}) ez da aurkitu. UTC-ra itzultzen. Mesedez, aldatu zure ordu-eremua ezarpenetan eta eman arazoaren berri.",
    "No more events today" : "Ez dago gertaera gehiagorik gaurkoz.",
    "No upcoming events" : "Ez dago gertaerarik datozen egunetan.",
    "Create a new event" : "Sortu gertaera berri bat",
    "[Today]" : "[Gaur]",
    "[Tomorrow]" : "[Bihar]",
    "[Yesterday]" : "[Atzo]",
    "Event does not exist" : "Ez dago gertaera hori",
    "Delete this occurrence" : "Ezabatu gertaera hau",
    "Delete this and all future" : "Ezabatu hau eta etorkizunekoak",
    "Details" : "Xehetasunak",
    "Attendees" : "Partaideak",
    "Reminders" : "Oroigarriak",
    "Close" : "Itxi",
    "Show more details" : "Erakutsi xehetasun gehiago",
    "Subscribe to {name}" : "Harpidetu {name}",
    "Download {name}" : "Deskargatu {name}",
    "Anniversary" : "Urtebetetzea / urteurrena",
    "Appointment" : "Hitzordua",
    "Business" : "Lana",
    "Education" : "Hezkuntza",
    "Holiday" : "Jaieguna",
    "Meeting" : "Bilera",
    "Miscellaneous" : "Askotarikoa",
    "Non-working hours" : "Laneko orduetatik kanpo",
    "Not in office" : "Ez nago bulegoan",
    "Phone call" : "Telefono deia",
    "Sick day" : "Gaixotasuna",
    "Special occasion" : "Gertaera berezia",
    "Travel" : "Bidaia",
    "Vacation" : "Oporrak",
    "Midnight on the day the event starts" : "Gauerdian gertaera hasten den egunean",
    "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["Egun %n gertaera hasi baino lehen {formattedHourMinute}(e)tan","%n egun gertaera hasi baino lehen {formattedHourMinute}(e)tan"],
    "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : [" aste %n gertaera hasi baino lehen {formattedHourMinute}(e)tan","%n aste gertaera hasi baino lehen {formattedHourMinute}(e)tan"],
    "on the day of the event at {formattedHourMinute}" : "Gertaeraren egunean {formattedHourMinute}(e)tan",
    "at the event's start" : "gertaera hasieran",
    "at the event's end" : "gertaera amaieran",
    "{time} before the event starts" : "gertaera hasi baino {time} lehenago",
    "{time} before the event ends" : "gertaera amaitu baino {time} lehenago",
    "{time} after the event starts" : "gertaera hasi baino {time} geroago",
    "{time} after the event ends" : "gertaera amaitu baino {time} geroago",
    "on {time}" : "{time}(e)tan",
    "on {time} ({timezoneId})" : "{time}(e)tan ({timezoneId})",
    "Week {number} of {year}" : "{year}ko {number} astea",
    "Does not repeat" : "Ez errepikatu",
    "Daily" : "Egunero",
    "Weekly" : "Astero",
    "Monthly" : "Hilabetero",
    "Yearly" : "Urtero",
    "_Every %n day_::_Every %n days_" : ["Egunero","%n egunetik behin"],
    "_Every %n week_::_Every %n weeks_" : ["Astero","%n astetik behin"],
    "_Every %n month_::_Every %n months_" : ["Hilabetero","%n hilabetetik behin"],
    "_Every %n year_::_Every %n years_" : ["Urtero","%n urtetik behin"],
    "_on {weekday}_::_on {weekdays}_" : ["{weekday}","{weekdays}"],
    "_on day {dayOfMonthList}_::_on days {dayOfMonthList}_" : ["{dayOfMonthList} egunean","{dayOfMonthList} egunetan"],
    "on the {ordinalNumber} {byDaySet}" : "{ordinalNumber} {byDaySet}(e)an",
    "in {monthNames}" : "{monthNames}(e)an",
    "in {monthNames} on the {ordinalNumber} {byDaySet}" : "{monthNames}(e)an {ordinalNumber} {byDaySet}(e)an",
    "until {untilDate}" : "{untilDate} arte",
    "_%n time_::_%n times_" : ["%n","%naldiz"],
    "Untitled event" : "Izenik gabeko gertaera",
    "Untitled task" : "Izenik gabeko zeregina",
    "Please ask your administrator to enable the Tasks App." : "Mesedez eskatu administratzaileari Tasks aplikazioa gaitu dezan.",
    "prev" : "aurrekoa",
    "next" : "hurrengoa",
    "prev year" : "aurreko urtea",
    "next year" : "datorren urtea",
    "today" : "gaur",
    "list" : "zerrenda",
    "W" : "A. ",
    "all-day" : "Egun osoa",
    "%n more" : "%n gehiago",
    "No events to display" : "Ez dago bistaratzeko gertaerarik",
    "_+%n more_::_+%n more_" : ["+ %n","+ %n"],
    "No events" : "Ez dago gertaerarik",
    "Create a new event or change the visible time-range" : "Sortu gertaera berria edo aldatu ikusgai dagoen epea",
    "When shared show" : "Partekatzean erakutsi",
    "When shared show full event" : "Partekatzean erakutsi gertaera osoa",
    "When shared show only busy" : "Partekatzean okupatua bezala erakutsi soilik",
    "When shared hide this event" : "Partekatzean ezkutatu gertaera hau",
    "The visibility of this event in shared calendars." : "Gertaera honen ikusgarritasuna egutegi partekatuetan",
    "Location" : "Kokapena",
    "Add a location" : "Gehitu kokapen bat",
    "Description" : "Deskribapena",
    "Add a description" : "Gehitu deskribapena",
    "Status" : "Egoera",
    "Confirmed" : "Berretsita",
    "Tentative" : "Behin behinekoa",
    "Canceled" : "Utzita",
    "Confirmation about the overall status of the event." : "Baieztapena gertaeraren egoera orokorrari buruz.",
    "Show as" : "Erakutsi honela",
    "Take this event into account when calculating free-busy information." : "Kontuan izan gertaera hau libre-lanpetuta informazio kalkuluetan.",
    "Free" : "Libre",
    "Categories" : "Kategoriak",
    "Categories help you to structure and organize your events." : "Kategoriak lagungarri zaizkizu gertaerak egituratu eta antolatzeko.",
    "Search or add categories" : "Bilatu edo gehitu kategoriak",
    "Add this as a new category" : "Gehitu hau kategoria berri bezala",
    "Custom color" : "Kolore pertsonalizatua",
    "Special color of this event. Overrides the calendar-color." : "Gertaera honen kolorea berezia da. Egutegi kolorea baliogabetzen du.",
    "Chat room for event" : "Txat gela gertaera honentzat",
    "Imported {filename}" : "Inportatuta {filename}",
    "Meditation" : "Meditazioa",
    "Relaxing" : "Erlaxatzen",
    "Relax" : "Erlaxazioa",
    "Presentation" : "Aurkezpena",
    "Present" : "Aurkeztu",
    "Camping" : "Kanpina",
    "Camp" : "Kanpatu",
    "Movie" : "Filma",
    "Cinema" : "Zinema",
    "Graduation" : "Graduazioa",
    "Brainstorm" : "Ideia-jasa",
    "Baseball" : "Beisbola",
    "Meet" : "Topaketa",
    "Planning" : "Plangintza",
    "Pointing" : "Honi begira",
    "Retrospective" : "Atzera begirakoa",
    "Review" : "Berrikusi",
    "Office" : "Bulegoa",
    "Contributor week" : "Laguntzailearen astea",
    "Party" : "Jaia",
    "Celebration" : "Ospakizuna",
    "Mail" : "Posta",
    "Soccer" : "Futbola",
    "Football" : "Futbol amerikarra",
    "Gaming" : "Bideo-jokoak",
    "Play" : "Jolastu",
    "Game" : "Jokoa",
    "Drive" : "Gidatu",
    "Bicycle" : "Bizikleta",
    "Cycle" : "Bizikletan ibili",
    "Biking" : "Motorrean ibili",
    "Podcast" : "Podcasta",
    "Basketball" : "Saskibaloia",
    "Fishing" : "Arrantza",
    "Hiking" : "Ibilaldia egin",
    "Hike" : "Ibilaldia",
    "Art" : "Artea",
    "Exhibition" : "Erakusketa",
    "Museum" : "Museoa",
    "Pilates" : "Pilates",
    "Park" : "Parkea",
    "Studying" : "Ikasten",
    "Doctor" : "Medikua",
    "Health" : "Osasuna",
    "Dentist" : "Dentista",
    "Interview" : "Elkarrizketa",
    "Training" : "Entrenamendua",
    "Practice" : "Praktika",
    "Sports" : "Kirolak",
    "Exercise" : "Kirola egin",
    "Work out" : "Gimnasia",
    "Working out" : "Gimnasioan",
    "Gym" : "Gimnasioa",
    "Barber" : "Bizargina",
    "Haircut" : "Ilea moztu",
    "Exam" : "Azterketa",
    "Working" : "Lanean",
    "New Years Eve" : "Urtezaharra",
    "NYE" : "UZ",
    "Fireworks" : "Su artifizialak",
    "Running" : "Korrika",
    "Go for a run" : "Korrikaldia",
    "Marathon" : "Maratoia",
    "Video-conference" : "Bideo-konferentzia",
    "Conference-call" : "Konferentzia deia",
    "Video-call" : "Bideo-deia",
    "Video-chat" : "Bideo-txata",
    "Video-meeting" : "Bideo-bilera",
    "Call" : "Deia",
    "Calling" : "Deitzen",
    "Christmas" : "Eguberriak",
    "Conference" : "Biltzarra",
    "Pizza" : "Pizza",
    "Travelling" : "Bidaiatzen",
    "Journey" : "Bidaia",
    "Collaborate" : "Elkarlana",
    "Pair" : "Parekatu",
    "Lecture" : "Hitzaldia",
    "Seminar" : "Mintegia",
    "Photograph" : "Argazkia",
    "Celebrate" : "Ospatu",
    "Shopping" : "Erosketak",
    "Skate" : "Patinatu",
    "Skateboard" : "Patinetea",
    "Wine tasting" : "Ardo dastaketa",
    "Golf" : "Golfa",
    "Dinner" : "Afaria",
    "Lunch" : "Bazkaria",
    "Global" : "Orokorra"
},
"nplurals=2; plural=(n != 1);");
